@@ -49,11 +49,16 @@ class API:
         self.session.cookies.clear()
         if os.path.isfile(email+'.cookie'):
             self._load_cookies(email+'.cookie')
+            try:
+                self.user_id = self.session.cookies.get_dict()['c_user']
+            except:
+                logging.error('Cookies is invalid, remove cookies and try again')
+                return
         else:
-            url = 'https://www.facebook.com/'
+            url = 'https://mbasic.facebook.com/login'
             req = self.session.get(url)
             soup = BeautifulSoup(req.text,'lxml')
-            all_input_data = soup.find('form').findAll('input')
+            all_input_data = soup.find('form').findAll('input', {'type':'hidden'})
             data = {}
             for input_data in all_input_data:
                 data[input_data.get('name')] = input_data.get('value')
@@ -61,7 +66,7 @@ class API:
             data['email'] = email
             data['pass'] = password
             #login
-            login_url = 'https://www.facebook.com/login'
+            login_url = 'https://mbasic.facebook.com/login'
             req = self.session.post(login_url,data=data)
         self.user_id = self.session.cookies.get_dict()['c_user']
         # get hidden input data
@@ -283,6 +288,28 @@ class API:
                  )
         self.session.post(url, data=m_data, headers={'Content-Type': m_data.content_type})
 
+    def group_sell_post(self, 
+                        group_id,
+                        title, price,
+                        location='',
+                        content='',
+                        images=[],
+                        currency='TWD'):
+        url = 'https://mbasic.facebook.com/groups/sell/_edit/post/'
+        data = {}
+        data['fb_dtsg'] = self.fb_dtsg
+        data['composer_attachment_sell_title'] = title
+        data['composer_attachment_sell_price'] = str(price)
+        data['composer_attachment_sell_pickup_note'] = location
+        data['composer_attachment_sell_currency'] = currency
+        data['target'] = str(group_id)
+        for i, image in enumerate(images[:3]):
+            data['file%d'%i] = image
+        data['xc_message'] = content
+        m_data = MultipartEncoder(
+                        fields = data
+                )
+        self.session.post(url, data=m_data, headers={'Content-Type': m_data.content_type})
     # comment methods
     def get_comments(self, post_id, group_id=None, num=10, start=0):
         if not self.login_check:
@@ -494,3 +521,20 @@ class API:
             self.send_msg_data['ids[%s]'%str(chat_room_id)] = str(chat_room_id)
         self.send_msg_data['body'] = content
         self.session.post(url, data=self.send_msg_data)
+
+    def send_image_msg(self, chat_room_id, image, content):
+        url = 'https://upload.facebook.com/_mupload_/mbasic/messages/attachment/photo/'
+        send_data = self.send_msg_data.copy()
+        if len(str(chat_room_id)) > len(self.user_id):
+            send_data['tids'] = 'cid.g.%s'%str(chat_room_id)
+        else:
+            send_data['tids'] = '%s'%str(chat_room_id)
+            send_data['ids[%s]'%str(chat_room_id)] = str(chat_room_id)
+        send_data['tids'] = 'cid.g.%s'%str(chat_room_id)
+        send_data['file1'] = ('image',image,'image')
+        send_data['body'] = content
+
+        m_data = MultipartEncoder(
+                        fields = send_data
+                 )
+        self.session.post(url, data=m_data, headers={'Content-Type': m_data.content_type})
\ No newline at end of file
